@@ -7,6 +7,7 @@ import os
 import glob
 from forest import (
         satellite,
+        screen,
         series,
         data,
         load,
@@ -26,6 +27,7 @@ from forest import (
         intake_loader,
         navigate,
         parse_args)
+import forest.components
 import forest.config as cfg
 import forest.middlewares as mws
 from forest.observe import Observable
@@ -45,11 +47,10 @@ def main(argv=None):
                     args.variables))
 
     # Full screen map
-    lon_range = (90, 140)
-    lat_range = (-23.5, 23.5)
+    viewport = config.default_viewport
     x_range, y_range = geo.web_mercator(
-        lon_range,
-        lat_range)
+        viewport.lon_range,
+        viewport.lat_range)
     figure = bokeh.plotting.figure(
         x_range=x_range,
         y_range=y_range,
@@ -84,15 +85,9 @@ def main(argv=None):
             low=0,
             high=1,
             palette=bokeh.palettes.Plasma[256])
-    for figure in figures:
-        colorbar = bokeh.models.ColorBar(
-            color_mapper=color_mapper,
-            orientation="horizontal",
-            background_fill_alpha=0.,
-            location="bottom_center",
-            major_tick_line_color="black",
-            bar_line_color="black")
-        figure.add_layout(colorbar, 'center')
+
+    # Colorbar user interface
+    colorbar_ui = forest.components.ColorbarUI(color_mapper)
 
     # Database/File system loader(s)
     for group in config.file_groups:
@@ -228,10 +223,6 @@ def main(argv=None):
         db.InverseCoordinate("pressure"),
         db.next_previous,
         db.Controls(navigator),
-        db.Converter({
-            "valid_times": db.stamps,
-            "inital_times": db.stamps
-        }),
         colors.palettes,
         presets.Middleware(presets.proxy_storage(config.presets_file)),
         presets.middleware,
@@ -247,6 +238,10 @@ def main(argv=None):
         initial_state=initial_state,
         middlewares=middlewares)
 
+    # Add time user interface
+    time_ui = forest.components.TimeUI()
+    time_ui.connect(store)
+
     # Connect renderer.visible states to store
     artist = layers.Artist(renderers)
     artist.connect(store)
@@ -259,6 +254,10 @@ def main(argv=None):
     tools_panel = series.ToolsPanel()
     tools_panel.connect(store)
 
+    # Connect tap listener
+    tap_listener = screen.TapListener()
+    tap_listener.connect(store)
+
     # Connect figure controls/views
     figure_ui = layers.FigureUI()
     figure_ui.add_subscriber(store.dispatch)
@@ -278,8 +277,7 @@ def main(argv=None):
 
     # Connect navigation controls
     controls = db.ControlView()
-    controls.add_subscriber(store.dispatch)
-    store.add_subscriber(controls.render)
+    controls.connect(store)
 
     def old_world(state):
         kwargs = {k: state.get(k, None) for k in db.State._fields}
@@ -287,6 +285,9 @@ def main(argv=None):
 
     connector = layers.ViewerConnector(viewers, old_world).connect(store)
 
+    # Set default time series visibility
+    store.dispatch(series.on_toggle())
+
     # Set top-level navigation
     store.dispatch(db.set_value("patterns", config.patterns))
 
@@ -336,21 +337,6 @@ def main(argv=None):
     tool_layout = series.ToolLayout(series_figure)
     tool_layout.connect(store)
 
-    def place_marker(figure, source):
-        figure.circle(
-                x="x",
-                y="y",
-                color="red",
-                source=source)
-        def cb(event):
-            source.data = {
-                    "x": [event.x],
-                    "y": [event.y]}
-        return cb
-
-    marker_source = bokeh.models.ColumnDataSource({
-            "x": [],
-            "y": []})
     series_view = series.SeriesView.from_groups(
             series_figure,
             config.file_groups)
@@ -363,8 +349,8 @@ def main(argv=None):
     series_args.map(lambda a: series_view.render(*a))
     series_args.map(print)  # Note: map(print) creates None stream
     for f in figures:
-        f.on_event(bokeh.events.Tap, series_view.on_tap)
-        f.on_event(bokeh.events.Tap, place_marker(f, marker_source))
+        f.on_event(bokeh.events.Tap, tap_listener.update_xy)
+        marker = screen.MarkDraw(f).connect(store)
 
 
     # Minimise controls to ease navigation
@@ -412,6 +398,10 @@ def main(argv=None):
     document.title = "FOREST"
     document.add_root(control_root)
     document.add_root(tool_layout.figures_row)
+    document.add_root(
+        bokeh.layouts.row(time_ui.layout, name="time"))
+    document.add_root(
+        bokeh.layouts.row(colorbar_ui.layout, name="colorbar"))
     document.add_root(figure_row.layout)
     document.add_root(key_press.hidden_button)
 
